@@ -2,9 +2,9 @@ from .bunyan import BunyanFormat
 from .simpjson import JSONFormat
 from .advjson import AdvJSONFormat
 
-__package__ = "PyLogFormats"
+__package__ = "pyLogFormats"
 __author__ = "Matt Limb <matt.limb17@gmail.com>"
-__version__ = "0.1"
+__version__ = "0.1.1"
 
 
 __all__ = [
